@@ -1,12 +1,9 @@
-use crate::theme::Theme;
-
 #[allow(dead_code)]
 #[derive(Debug, Default, Clone)]
 pub struct Config {
+    pub moyu: bool,
     pub config_path: String,
     pub show_help: bool,
-    pub color_theme: Theme,
-    pub show_themes: bool,
 }
 
 impl From<crate::cli::Args> for Config {
@@ -18,10 +15,9 @@ impl From<crate::cli::Args> for Config {
 
         let config_path = args.path.unwrap_or(home);
         Config {
+            moyu: args.moyu,
             config_path,
             show_help: args.show_help,
-            color_theme: args.color_theme,
-            show_themes: args.show_themes,
         }
     }
 }
